@@ -4,16 +4,16 @@ from edc_action_item.models.action_model_mixin import ActionModelMixin
 from edc_consent.field_mixins.identity_fields_mixin import IdentityFieldsMixin
 from edc_consent.field_mixins.personal_fields_mixin import PersonalFieldsMixin
 from edc_consent.model_mixins import ConsentModelMixin
-from edc_identifier.managers import SubjectIdentifierManager
 from edc_identifier.model_mixins import NonUniqueSubjectIdentifierModelMixin
-from edc_model.models import BaseUuidModel, HistoricalRecords
+from edc_model.models import BaseUuidModel
 from edc_registration.model_mixins import UpdatesOrCreatesRegistrationModelMixin
 from edc_sites.models import SiteModelMixin
 from edc_utils import get_utcnow
-from edc_visit_schedule.model_mixins import CurrentSiteManager, OnScheduleModelMixin
+from edc_visit_schedule.model_mixins import OnScheduleModelMixin
 from edc_visit_schedule.model_mixins.off_schedule_model_mixin import (
     OffScheduleModelMixin,
 )
+from edc_visit_tracking.model_mixins import VisitModelMixin
 
 from edc_adverse_event.constants import STUDY_TERMINATION_CONCLUSION_ACTION
 from edc_adverse_event.model_mixins import (
@@ -29,10 +29,10 @@ from edc_adverse_event.model_mixins import (
 
 
 class SubjectConsent(
+    SiteModelMixin,
     ConsentModelMixin,
     PersonalFieldsMixin,
     IdentityFieldsMixin,
-    SiteModelMixin,
     NonUniqueSubjectIdentifierModelMixin,
     UpdatesOrCreatesRegistrationModelMixin,
     BaseUuidModel,
@@ -41,26 +41,20 @@ class SubjectConsent(
         pass
 
 
-class SubjectVisit(NonUniqueSubjectIdentifierModelMixin, BaseUuidModel):
+class SubjectVisit(SiteModelMixin, VisitModelMixin, BaseUuidModel):
+
+    pass
+
+
+class CrfOne(SiteModelMixin, NonUniqueSubjectIdentifierModelMixin, BaseUuidModel):
 
     report_datetime = models.DateTimeField(default=get_utcnow)
 
 
-class CrfOne(NonUniqueSubjectIdentifierModelMixin, BaseUuidModel):
-
-    report_datetime = models.DateTimeField(default=get_utcnow)
-
-
-class OnSchedule(OnScheduleModelMixin, BaseUuidModel):
+class OnSchedule(SiteModelMixin, OnScheduleModelMixin, BaseUuidModel):
 
     """A model used by the system. Auto-completed by subject_consent."""
 
-    on_site = CurrentSiteManager()
-
-    objects = SubjectIdentifierManager()
-
-    history = HistoricalRecords()
-
     def put_on_schedule(self):
         pass
 
@@ -68,7 +62,9 @@ class OnSchedule(OnScheduleModelMixin, BaseUuidModel):
         pass
 
 
-class StudyTerminationConclusion(ActionModelMixin, OffScheduleModelMixin, BaseUuidModel):
+class StudyTerminationConclusion(
+    SiteModelMixin, ActionModelMixin, OffScheduleModelMixin, BaseUuidModel
+):
 
     action_name = STUDY_TERMINATION_CONCLUSION_ACTION
 
