@@ -1,6 +1,6 @@
 from django.db import models
 from edc_action_item.managers import (
-    ActionIdentifierManager,
+    ActionIdentifierModelManager,
     ActionIdentifierSiteManager,
 )
 from edc_action_item.models import ActionModelMixin
@@ -17,6 +17,8 @@ from .ae_initial_tmg_model_mixin import AeInitialTmgModelMixin
 
 
 class AeInitialModelMixin(
+    SiteModelMixin,
+    ActionModelMixin,
     NonUniqueSubjectIdentifierFieldMixin,
     AeInitialFieldsModelMixin,
     AeInitialMethodsModelMixin,
@@ -24,8 +26,6 @@ class AeInitialModelMixin(
     AeInitialSaeModelMixin,
     AeInitialSusarModelMixin,
     AeInitialTmgModelMixin,
-    SiteModelMixin,
-    ActionModelMixin,
     models.Model,
 ):
 
@@ -33,7 +33,7 @@ class AeInitialModelMixin(
 
     on_site = ActionIdentifierSiteManager()
 
-    objects = ActionIdentifierManager()
+    objects = ActionIdentifierModelManager()
 
     class Meta:
         abstract = True
