@@ -1,6 +1,6 @@
 from django.db import models
 from edc_action_item.managers import (
-    ActionIdentifierManager,
+    ActionIdentifierModelManager,
     ActionIdentifierSiteManager,
 )
 from edc_action_item.models import ActionModelMixin
@@ -15,12 +15,12 @@ from .ae_susar_methods_model_mixin import AeSusarMethodsModelMixin
 
 
 class AeSusarModelMixin(
-    NonUniqueSubjectIdentifierFieldMixin,
-    AeSusarFieldsModelMixin,
     AeSusarMethodsModelMixin,
-    ReportStatusModelMixin,
     SiteModelMixin,
     ActionModelMixin,
+    NonUniqueSubjectIdentifierFieldMixin,
+    AeSusarFieldsModelMixin,
+    ReportStatusModelMixin,
     models.Model,
 ):
 
@@ -28,7 +28,7 @@ class AeSusarModelMixin(
 
     on_site = ActionIdentifierSiteManager()
 
-    objects = ActionIdentifierManager()
+    objects = ActionIdentifierModelManager()
 
     class Meta:
         abstract = True
