@@ -1,10 +1,19 @@
 from django.conf import settings
 from django.db import models
-from edc_constants.choices import YES_NO
+from edc_constants.choices import YES_NO, YES_NO_NA
+from edc_constants.constants import NOT_APPLICABLE
 from edc_model.validators import datetime_not_future
 from edc_model_fields.fields import OtherCharField
 from edc_utils import get_utcnow
 
+from edc_adverse_event.models import AeClassification
+
+
+def get_investigator_ae_classification_choices():
+    choices = [(obj.name, obj.display_name) for obj in AeClassification.objects.all()]
+    choices.append((NOT_APPLICABLE, "Not applicable"))
+    return tuple(choices)
+
 
 class AeTmgFieldsModelMixin(models.Model):
 
@@ -51,7 +60,34 @@ class AeTmgFieldsModelMixin(models.Model):
         help_text="If No, explain in the narrative below",
     )
 
-    narrative = models.TextField(verbose_name="Narrative", blank=True, null=True)
+    investigator_narrative = models.TextField(verbose_name="Narrative", blank=True, null=True)
+
+    investigator_ae_classification_agreed = models.CharField(
+        verbose_name=(
+            "Does this investigator agree with the AE classification on the "
+            "original AE report?"
+        ),
+        max_length=15,
+        choices=YES_NO_NA,
+        blank=False,
+        default=NOT_APPLICABLE,
+        help_text="If No, select a classification below",
+    )
+
+    investigator_ae_classification = models.ForeignKey(
+        AeClassification,
+        on_delete=models.PROTECT,
+        verbose_name="Adverse Event (AE) Classification",
+        null=True,
+        blank=False,
+        help_text=(
+            "Only applicable if this investigator does not agree with the original AE report"
+        ),
+    )
+
+    investigator_ae_classification_other = OtherCharField(
+        max_length=250, blank=True, null=True
+    )
 
     officials_notified = models.DateTimeField(
         blank=True,
