@@ -1,9 +1,11 @@
 from .death_report_extra_fields_model_mixin import DeathReportExtraFieldsModelMixin
 from .death_report_model_mixin import DeathReportModelMixin
 from .death_report_tmg_model_mixin import (
+    DeathReportTmgManager,
     DeathReportTmgModelMixin,
     DeathReportTmgSecondManager,
     DeathReportTmgSecondModelMixin,
     DeathReportTmgSecondSiteManager,
+    DeathReportTmgSiteManager,
 )
 from .simple_death_report_model_mixin import SimpleDeathReportModelMixin
